summaryrefslogtreecommitdiff
path: root/Command/Sync.hs
diff options
context:
space:
mode:
authorGravatar Joey Hess <joeyh@joeyh.name>2015-04-10 17:08:07 -0400
committerGravatar Joey Hess <joeyh@joeyh.name>2015-04-10 17:08:07 -0400
commitc7a5cc5cc31377e5fed1fc59bfdeb503784d060d (patch)
tree2acb62d5fef9a1b2a02cbc43fa8c81b7108c91f1 /Command/Sync.hs
parentb4dd6c2250efd959c2b0c0d032d9508ef55ea79a (diff)
get, move, copy, mirror: Concurrent downloads and uploads are now supported!
This works, and seems fairly robust. Clean get of 20 files at -J3. At -J10, there are some messages about ssh multiplexing, probably due to a race spinning up the ssh connection cacher. But, it manages to get all the files ok regardless. The progress bars are a scrambled mess though, due to bugs in ascii-progress, which I've already filed. Particularly this one: https://github.com/yamadapc/haskell-ascii-progress/issues/8
Diffstat (limited to 'Command/Sync.hs')
-rw-r--r--Command/Sync.hs6
1 files changed, 3 insertions, 3 deletions
diff --git a/Command/Sync.hs b/Command/Sync.hs
index 130693909..7c1ed0067 100644
--- a/Command/Sync.hs
+++ b/Command/Sync.hs
@@ -389,7 +389,7 @@ syncFile rs f k = do
u <- getUUID
let locs' = concat [[u | got], putrs, locs]
- -- Using callCommandAction rather than commandAction for drops,
+ -- Using callCommandAction rather than includeCommandAction for drops,
-- because a failure to drop does not mean the sync failed.
handleDropsFrom locs' rs "unwanted" True k (Just f)
Nothing callCommandAction
@@ -403,7 +403,7 @@ syncFile rs f k = do
( return [ get have ]
, return []
)
- get have = commandAction $ do
+ get have = includeCommandAction $ do
showStart "get" f
next $ next $ getViaTmp k $ \dest -> getKeyFile' k (Just f) dest have
@@ -415,7 +415,7 @@ syncFile rs f k = do
, return []
)
put dest = do
- ok <- commandAction $ do
+ ok <- includeCommandAction $ do
showStart "copy" f
Command.Move.toStart' dest False (Just f) k
return (ok, if ok then Just (Remote.uuid dest) else Nothing)